TEAM_DETAILS_URI = "https://stats.nba.com/stats/teamdetails?"
COMMON_TEAM_ROSTER_URI = "https://stats.nba.com/stats/commonteamroster?"
FRANCHISE_LEADER_URI = "https://stats.nba.com/stats/franchiseleaders?"

TEAMS = {
    "Celtics": 1610612738,
    "Spurs": 1610612759
}



REQ_HEADER = {
    "Connection": "keep-alive",
    "Accept": "application/json, text/plain, */*",
    "x-nba-stats-token": "true",
    "User-Agent": "Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/84.0.4147.89 Safari/537.36",
    "x-nba-stats-origin": "stats",
    "Referer": "https://stats.nba.com/",
    "Accept-Language": "en-US,en;q=0.9,zh-CN;q=0.8,zh;q=0.7"
}



import requests
import pprint
from python_nbaclient import REQ_HEADER, constants


class TeamDetails:
    def __init__(self, team_id):
        """
        :param team_id: id of the team
        """
        self._url = constants.TEAM_DETAILS_URI
        self._api_param = {"teamID": team_id}
        self._headers = REQ_HEADER
        response = requests.get(self._url,
                                headers=self._headers,
                                params=self._api_param)
        if response.status_code == 200:
            self.team_details = response.json()
            pp = pprint.PrettyPrinter(indent=2)
            pp.pprint(self.team_details)
        else:
            # ToDo: Error Log and a generic way of handling error
            print("Error")

    # ToDo: parse the json and return the useful information
    def details(self):
        pass


class CommonTeamRoster:
    # ToDo: league_id: 00 means?, season: current year?
    def __init__(self, team_id, season, league_id="00"):
        """
        :param team_id: id of the team
        :param season: NBA season, String, "2019-20"
        :param league_id: NBA league ID, String
        """

        self._url = constants.COMMON_TEAM_ROSTER_URI
        self._api_param = {
            "TeamID": team_id,
            "LeagueID": league_id,
            "Season": season
        }

        self._headers = REQ_HEADER

        response = requests.get(self._url,
                                headers=self._headers,
                                params=self._api_param)
        if response.status_code == 200:
            self.team_roster = response.json()
            pp = pprint.PrettyPrinter(indent=2)
            pp.pprint(self.team_roster)
        else:
            print("Error")

    # ToDo: parse the json output and return info
    def rosters(self):
        pass


class FranchiseLeaders:
    def __init__(self, team_id):
        """
        :param team_id: id of the team
        """
        self._url = constants.FRANCHISE_LEADER_URI
        self._api_param = {"TeamID": team_id}
        self._headers = REQ_HEADER

        response = requests.get(self._url,
                                headers=self._headers,
                                params=self._api_param)
        if response.status_code == 200:
            self.franchise_leader = response.json()
            pp = pprint.PrettyPrinter(indent=2)
            pp.pprint(self.franchise_leader)
        else:
            print("Error")

    def franchise(self):
        pass



from setuptools import setup, find_packages

with open("README.md", "r") as fh:
    long_description = fh.read()

setup(
    name="python_nbaclient",
    version="0.0.3",
    author="Lucas H. Xu",
    author_email="lucasxu.pub@gmail.com",
    description="A Python Wrapper of NBA RESTful Stats APIs",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/xuhang57/python_nbaclient",
    packages=find_packages(),
    install_requires=['requests', 'pprint'],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
)
